@@ -1,7 +1,7 @@
 ## UI.R
 function(request) {
   fluidPage(
-    titlePanel(NULL, windowTitle = "RLumShiny - RadialPlot"),
+    titlePanel("Radial Plot", windowTitle = "RLumShiny - Radial Plot"),
     sidebarLayout(
       # 2- width = 5 -> refers to twitters bootstrap grid system
       # where the the maximum width is 12 that is to be shared between all
@@ -16,10 +16,12 @@ function(request) {
                                         # file upload button (data set 1)
                                         fileInput(inputId = "file1",
                                                   label = strong("Primary data set"),
+                                                  placeholder = "A CSV file with two columns (De and De error)",
                                                   accept="text/plain, .csv, text/csv"),
                                         # file upload button (data set 2)
                                         fileInput(inputId = "file2",
                                                   label = strong("Secondary data set"),
+                                                  placeholder = "A CSV file with two columns (De and De error)",
                                                   accept="text/plain, .csv, text/csv"),
                                         # rhandsontable input/output
                                         fluidRow(
@@ -30,8 +32,8 @@ function(request) {
                                                  rHandsontableOutput(outputId = "table_in_secondary"))
                                         ),
                                         hr(),
-                                        actionButton(inputId = "refresh", label = "Refresh", icon = icon("fas fa-sync")),
-                                        tooltip(refId = "refresh", text = "Redraw the plot")
+                                        actionButton(inputId = "refresh", label = "Refresh",
+                                                     icon = icon("fas fa-sync"), title = "Redraw the plot.")
                                ),##EndOf::Tab_1
 
                                # Tab 2: Statistical information
@@ -42,7 +44,7 @@ function(request) {
                                                  checkboxInput(inputId = "summary",
                                                                label = "Show summary",
                                                                value = FALSE),
-                                                 tooltip(refId = "summary", text = "Adds numerical output to the plot")
+                                                 title = "Add numerical output to the plot."
                                           ),
                                           column(width = 6,
                                                  selectInput(inputId = "sumpos",
@@ -57,36 +59,37 @@ function(request) {
                                                                                      "Bottom left" = "bottomleft",
                                                                                      "Bottom right" = "bottomright")
                                                              )),
-                                                 tooltip(refId = "sumpos", attr = "for", text = "Position of the statistical summary. The keyword \"Subtitle\" will only work if no plot subtitle is used.")
+                                                 title = "Position of the statistical summary. The keyword \"Subtitle\" will only work if no plot subtitle is used."
                                           )
                                         ),
-                                        checkboxGroupInput(inputId = "stats",
-                                                           label = "Parameters",
-                                                           selected = c("n","mean"),
-                                                           choices = c("n" = "n",
-                                                                       "Mean" = "mean",
-                                                                       "weighted Mean" = "mean.weighted",
-                                                                       "Median" = "median",
-                                                                       "weighted Median" = "median.weighted",
-                                                                       "rel. Standard deviation" = "sdrel",
-                                                                       "abs. Standard deviation" = "sdabs",
-                                                                       "rel. Standard error" = "serel",
-                                                                       "abs. Standard error" = "seabs",
-                                                                       #"25 % Quartile" = "q25", #not implemented yet
-                                                                       #"75 % Quartile" = "q75", #not implemented yet
-                                                                       "KDEmax"  = "kdemax",
-                                                                       "Skewness" = "skewness",
-                                                                       "Kurtosis" = "kurtosis"
-                                                           )),
-                                        tooltip(refId = "stats", text = "Statistical parameters to be shown in the summary"),
+                                        div(align = "left",
+                                            checkboxGroupInput(inputId = "stats",
+                                                               label = "Parameters",
+                                                               selected = c("n", "mean"),
+                                                               choices = c("n" = "n",
+                                                                           "Mean" = "mean",
+                                                                           "weighted Mean" = "mean.weighted",
+                                                                           "Median" = "median",
+                                                                           "weighted Median" = "median.weighted",
+                                                                           "rel. Standard deviation" = "sdrel",
+                                                                           "abs. Standard deviation" = "sdabs",
+                                                                           "rel. Standard error" = "serel",
+                                                                           "abs. Standard error" = "seabs",
+                                                                           #"25 % Quartile" = "q25", #not implemented yet
+                                                                           #"75 % Quartile" = "q75", #not implemented yet
+                                                                           "KDEmax"  = "kdemax",
+                                                                           "Skewness" = "skewness",
+                                                                           "Kurtosis" = "kurtosis")
+                                                               ),
+                                            title = "Statistical parameters to be shown in the summary."),
                                         br(),
                                         div(align = "center", h5("Datapoint labels")),
                                         div(align = "center", checkboxGroupInput(inputId = "statlabels", inline = TRUE,
                                                                                  label = NULL,
                                                                                  choices = c("Min" = "min",
                                                                                              "Max" = "max",
-                                                                                             "Median" = "median"))),
-                                        tooltip(refId = "statlabels", text = "Additional labels of statistically important values in the plot.")
+                                                                                             "Median" = "median")),
+                                            title = "Additional labels of statistically important values in the plot.")
                                ),##EndOf::Tab_2
 
                                # Tab 3: input that refer to the plot rather than the data
@@ -109,7 +112,7 @@ function(request) {
                                           column(width = 6,
                                                  # inject sliderInput from Server.R
                                                  uiOutput(outputId = "centValue"),
-                                                 tooltip(refId = "centValue", text = "User-defined central value, primarily used for horizontal centering of the z-axis")
+                                                 title = "User-defined central value, primarily used for horizontal centering of the z-axis."
                                           ),
                                           column(width = 6,
                                                  sliderInput(inputId = "cex",
@@ -118,13 +121,14 @@ function(request) {
                                                              value = 1.0, step = 0.1)
                                           )
                                         ),
-                                        selectInput(inputId = "centrality",
-                                                    label = "Centrality",
-                                                    list("Mean" = "mean",
-                                                         "Median" = "median",
-                                                         "Weighted mean" = "mean.weighted",
-                                                         "Weighted median" = "median.weighted")),
-                                        tooltip(refId = "centrality", attr = "for", text = "Measure of centrality, used for the standardisation, centering the plot and drawing the central line.")
+                                        div(align = "left",
+                                            selectInput(inputId = "centrality",
+                                                        label = "Centrality",
+                                                        list("Mean" = "mean",
+                                                             "Median" = "median",
+                                                             "Weighted mean" = "mean.weighted",
+                                                             "Weighted median" = "median.weighted")),
+                                            title = "Measure of centrality, used for the standardisation, centering the plot and drawing the central line.")
                                ),##EndOf::Tab_3
 
                                # Tab 4: modify axis parameters
@@ -134,7 +138,7 @@ function(request) {
                                           column(width = 6,
                                                  textInput(inputId = "xlab1",
                                                            label = "Label x-axis (upper)",
-                                                           value = "Relative error [%]")
+                                                           value = "Relative standard error [%]")
                                           ),
                                           column(width = 6,
                                                  textInput(inputId = "xlab2",
@@ -145,27 +149,30 @@ function(request) {
                                         # inject sliderInput from Server.R
                                         uiOutput(outputId = "xlim"),
                                         div(align = "center", h5("Y-axis")),
-                                        checkboxInput(inputId = "yticks",
-                                                      label = HTML("Show &plusmn;2&sigma; label"),
-                                                      value = TRUE),
-                                        tooltip(refId = "yticks", text = "Option to hide y-axis labels."),
+                                        div(align = "left",
+                                            checkboxInput(inputId = "yticks",
+                                                          label = HTML("Show &plusmn;2&sigma; label"),
+                                                          value = TRUE),
+                                            title = "Hide y-axis labels."),
                                         textInput(inputId = "ylab",
                                                   label = "Label y-axis",
                                                   value = "Standardised estimate"),
                                         div(align = "center", h5("Z-axis")),
-                                        checkboxInput(inputId = "logz",
-                                                      label = "Logarithmic z-axis",
-                                                      value = TRUE),
-                                        tooltip(refId = "logz", text = "Option to display the z-axis in logarithmic scale."),
+                                        div(align = "left",
+                                            checkboxInput(inputId = "logz",
+                                                          label = "Logarithmic z-axis",
+                                                          value = TRUE),
+                                            title = "Display the z-axis in logarithmic scale."),
                                         textInput(inputId = "zlab",
                                                   label = "Label z-axis",
                                                   value = "Equivalent dose [Gy]"),
                                         # inject sliderInput from Server.R
                                         uiOutput(outputId = "zlim"),
-                                        sliderInput('curvature', 'Z-axis curvature',
-                                                    min=0, max=3,
-                                                    value=4.5/5.5, step=0.01, round=FALSE),
-                                        tooltip(refId = "curvature", attr = "for", text = "User-defined plot area ratio (i.e. curvature of the z-axis). If omitted, the default value (4.5/5.5) is used and modified automatically to optimise the z-axis curvature. The parameter should be decreased when data points are plotted outside the z-axis or when the z-axis gets too elliptic.")
+                                        div(align = "left",
+                                            sliderInput('curvature', 'Z-axis curvature',
+                                                        min = 0, max = 3,
+                                                        value = 4.5/5.5, step = 0.01, round = FALSE),
+                                            title = "User-defined plot area ratio (i.e. curvature of the z-axis). If omitted, the default value (4.5/5.5) is used and modified automatically to optimise the z-axis curvature. The parameter should be decreased when data points are plotted outside the z-axis or when the z-axis gets too elliptic.")
                                ),##EndOf::Tab_4
 
                                # Tab 5: modify data point representation
@@ -173,38 +180,14 @@ function(request) {
                                         div(align = "center", h5("Primary data set")),
                                         fluidRow(
                                           column(width = 6,
-                                                 selectInput(inputId = "pch",
-                                                             label = "Style",
-                                                             selected = "17",
-                                                             choices = c("Square"= "1",
-                                                                         "Circle"="2",
-                                                                         "Triangle point up"="3",
-                                                                         "Plus"="4",
-                                                                         "Cross"="5",
-                                                                         "Diamond"="6",
-                                                                         "Triangle point down"="7",
-                                                                         "Square cross"="8",
-                                                                         "Star"="9",
-                                                                         "Diamond plus"="10",
-                                                                         "Circle plus"="11",
-                                                                         "Triangles up and down"="12",
-                                                                         "Square plus"="13",
-                                                                         "Circle cross"="14",
-                                                                         "Square and Triangle down"="15",
-                                                                         "filled Square"="16",
-                                                                         "filled Circle"="17",
-                                                                         "filled Triangle point up"="18",
-                                                                         "filled Diamond"="19",
-                                                                         "solid Circle"="20",
-                                                                         "Bullet (smaller Circle)"="21",
-                                                                         "Custom"="custom"))
+                                                 pointSymbolChooser(inputId = "pch",
+                                                                    selected = "16")
                                           ),
                                           column(width = 6,
                                                  # show only if custom symbol is desired
                                                  conditionalPanel(condition = "input.pch == 'custom'",
-                                                                  textInput(inputId = "custompch",
-                                                                            label = "Insert character",
-                                                                            value = "?"))
+                                                                  customSymbolChooser(inputId = "custompch")
+                                                                  )
                                           )
                                         ),
                                         fluidRow(
@@ -228,38 +211,14 @@ function(request) {
                                         fluidRow(
                                           column(width = 6,
                                                  ## DATA SET 2
-                                                 selectInput(inputId = "pch2",
-                                                             label = "Style",
-                                                             selected = "17",
-                                                             choices = c("Square"= "1",
-                                                                         "Circle"="2",
-                                                                         "Triangle point up"="3",
-                                                                         "Plus"="4",
-                                                                         "Cross"="5",
-                                                                         "Diamond"="6",
-                                                                         "Triangle point down"="7",
-                                                                         "Square cross"="8",
-                                                                         "Star"="9",
-                                                                         "Diamond plus"="10",
-                                                                         "Circle plus"="11",
-                                                                         "Triangles up and down"="12",
-                                                                         "Square plus"="13",
-                                                                         "Circle cross"="14",
-                                                                         "Square and Triangle down"="15",
-                                                                         "filled Square"="16",
-                                                                         "filled Circle"="17",
-                                                                         "filled Triangle point up"="18",
-                                                                         "filled Diamond"="19",
-                                                                         "solid Circle"="20",
-                                                                         "Bullet (smaller Circle)"="21",
-                                                                         "Custom"="custom"))
+                                                 pointSymbolChooser(inputId = "pch2",
+                                                                    selected = "16")
                                           ),
                                           column(width = 6,
                                                  # show only if custom symbol is desired
                                                  conditionalPanel(condition = "input.pch2 == 'custom'",
-                                                                  textInput(inputId = "custompch2",
-                                                                            label = "Insert character",
-                                                                            value = "?"))
+                                                                  customSymbolChooser(inputId = "custompch2")
+                                                                  )
                                           )
                                         ),
                                         fluidRow(
@@ -288,10 +247,11 @@ function(request) {
                                         # options for custom lines:
                                         # 1 - z-value, 2 - color, 3 - label
                                         # only the options for the first line are shown
-                                        numericInput(inputId = "line1",
-                                                     label = strong("Line #1"),
-                                                     value =  NA, min = 0),
-                                        tooltip(refId = "line1", text = "Numeric values of the additional lines to be added."),
+                                        div(align = "left",
+                                            numericInput(inputId = "line1",
+                                                         label = strong("Line #1"),
+                                                         value =  NA, min = 0),
+                                            title = "Numeric values of the additional lines to be added."),
                                         fluidRow(
                                           column(width = 6,
                                                  HTML("Choose a color<br>"),
@@ -447,7 +407,7 @@ function(request) {
                                                              list("Grey" = "grey",
                                                                   "Custom" = "custom",
                                                                   "None" = "none")),
-                                                 tooltip(refId = "grid", attr = "for", text = "colour of the grid lines (originating at [0,0] and stretching to the z-scale). To disable grid lines, use \"none\".")
+                                                 title = "Colour of the grid lines (originating at [0,0] and stretching to the z-scale). To disable grid lines, use \"none\"."
                                           ),
                                           column(width = 6,
                                                  # show only if custom color is desired
@@ -469,7 +429,7 @@ function(request) {
                                                  checkboxInput(inputId = "showlegend",
                                                                label = "Show legend",
                                                                value = FALSE),
-                                                 tooltip(refId = "showlegend", text = "Legend content to be added to the plot.")
+                                                 title = "Legend content to be added to the plot."
                                           ),
                                           column(width = 6,
                                                  selectInput(inputId = "legend.pos",
@@ -512,9 +472,9 @@ function(request) {
                 # divide output in separate tabs via tabsetPanel
                 tabsetPanel(
                   tabPanel("Plot", plotOutput(outputId = "main_plot", height = "500px")),
-                  tabPanel("Primary data set", dataTableOutput("dataset")),
-                  tabPanel("Secondary data set", dataTableOutput("dataset2")),
-                  tabPanel("Central Age Model", dataTableOutput("CAM")),
+                  tabPanel("Primary data set", DT::DTOutput("dataset")),
+                  tabPanel("Secondary data set", DT::DTOutput("dataset2")),
+                  tabPanel("Central Age Model", DT::DTOutput("CAM")),
                   tabPanel("R plot code", verbatimTextOutput("plotCode"))
                 )###EndOf::tabsetPanel
       )##EndOf::mainPanel
